import { RpcMetadata } from "./rpc-metadata";
import { IMessageType } from "@protobuf-ts/runtime";
import { RpcInterceptor } from "./rpc-interceptor";
/**
 * User-provided options for Remote Procedure Calls.
 *
 * Every generated service method accepts these options.
 * They are passed on to the `RpcTransport` and can be evaluated there.
 */
export interface RpcOptions {
    /**
     * Meta data for the call.
     *
     * RPC meta data are simple key-value pairs that usually translate
     * directly to HTTP request headers.
     *
     * If a key ends with `-bin`, it should contain binary data in base64
     * encoding, allowing you to send serialized messages.
     */
    meta?: RpcMetadata;
    /**
     * Deadline for the call. Can be a specific date or a
     * timeout in milliseconds.
     */
    deadline?: Date | number;
    /**
     * Interceptors can be used to manipulate request and response data.
     * The most common use case is adding a "Authorization" header.
     */
    interceptors?: RpcInterceptor[];
    /**
     * To read or write `google.protobuf.Any` in JSON format, a type
     * registry must be provided so that the runtime can discriminate
     * the packed type.
     */
    typeRegistry?: IMessageType<any>[];
    /**
     * Ignore unknown fields? Defaults to false, which
     * means that an error is raised when unknown fields
     * are encountered in JSON or binary format.
     */
    ignoreUnknownFields?: boolean;
    /**
     * A `RpcTransport` implementation may allow arbitrary
     * other options.
     */
    [extra: string]: unknown;
}
/**
 * Merges custom RPC options with defaults. Returns a new instance and keeps
 * the "defaults" and the "options" unmodified.
 *
 * Merges `RpcMetadata` "meta", overwriting values from "defaults" with
 * values from "options". Does not append values to existing entries.
 *
 * Merges "typeRegistry" by creating a new array that contains types from
 * "options" first, then types from "defaults".
 *
 * Merges "interceptors" by creating a new array that contains interceptors
 * from "defaults" first, then interceptors from "options".
 *
 * Works with objects that extend `RpcOptions`, but only if the added
 * properties are of type Date, primitive like string, boolean, or Array
 * of primitives. If you have other property types, you have to merge them
 * yourself.
 */
export declare function mergeExtendedRpcOptions<T extends RpcOptions>(defaults: T, options?: Partial<T>): T;
//# sourceMappingURL=rpc-options.d.ts.map